@@ -61,7 +61,7 @@ GtkBuilder *    empathy_builder_get_file                (const gchar      *filen
 							 ...);
 void            empathy_builder_connect                 (GtkBuilder       *gui,
 							 gpointer          user_data,
-							 gchar            *first_object,
+							 const gchar      *first_object,
 							 ...);
 GtkWidget     *empathy_builder_unref_and_keep_widget    (GtkBuilder       *gui,
 							 GtkWidget        *root);
@@ -77,9 +77,10 @@ GdkPixbuf *   empathy_pixbuf_from_data_and_mime         (gchar            *data,
 							 gsize             data_size,
 							 gchar           **mime_type);
 void empathy_pixbuf_avatar_from_individual_scaled_async (FolksIndividual     *individual,
-							 GAsyncReadyCallback  callback,
 							 gint                 width,
 							 gint                 height,
+							 GCancellable        *cancellable,
+							 GAsyncReadyCallback  callback,
 							 gpointer             user_data);
 GdkPixbuf * empathy_pixbuf_avatar_from_individual_scaled_finish (
 							 FolksIndividual  *individual,
