@@ -590,6 +590,7 @@ new_chatroom_dialog_new_room_cb (EmpathyTpRoomlist        *room_list,
 	gchar            *tooltip;
 	const gchar      *need_password;
 	const gchar      *invite_only;
+	gchar            *tmp;
 
 	DEBUG ("New chatroom listed: %s (%s)",
 		empathy_chatroom_get_name (chatroom),
@@ -600,13 +601,15 @@ new_chatroom_dialog_new_room_cb (EmpathyTpRoomlist        *room_list,
 	selection = gtk_tree_view_get_selection (view);
 	store = GTK_LIST_STORE (dialog->model);
 	members = g_strdup_printf ("%d", empathy_chatroom_get_members_count (chatroom));
+	tmp = g_strdup_printf ("<b>%s</b>", empathy_chatroom_get_name (chatroom));
 	/* Translators: Room/Join's roomlist tooltip. Parameters are a channel name,
 	yes/no, yes/no and a number. */
-	tooltip = g_strdup_printf (_("<b>%s</b>\nInvite required: %s\nPassword required: %s\nMembers: %s"),
-		empathy_chatroom_get_name (chatroom),
+	tooltip = g_strdup_printf (_("%s\nInvite required: %s\nPassword required: %s\nMembers: %s"),
+		tmp,
 		empathy_chatroom_get_invite_only (chatroom) ? _("Yes") : _("No"),
 		empathy_chatroom_get_need_password (chatroom) ? _("Yes") : _("No"),
 		members);
+	g_free (tmp);
 	invite_only = (empathy_chatroom_get_invite_only (chatroom) ?
 		GTK_STOCK_INDEX : NULL);
 	need_password = (empathy_chatroom_get_need_password (chatroom) ?
@@ -714,7 +717,7 @@ static void
 new_chatroom_dialog_join (EmpathyNewChatroomDialog *dialog)
 {
 	EmpathyAccountChooser *account_chooser;
-	TpConnection          *connection;
+	TpAccount *account;
 	const gchar           *room;
 	const gchar           *server = NULL;
 	gchar                 *room_name = NULL;
@@ -723,7 +726,7 @@ new_chatroom_dialog_join (EmpathyNewChatroomDialog *dialog)
 	server = gtk_entry_get_text (GTK_ENTRY (dialog->entry_server));
 
 	account_chooser = EMPATHY_ACCOUNT_CHOOSER (dialog->account_chooser);
-	connection = empathy_account_chooser_get_connection (account_chooser);
+	account = empathy_account_chooser_get_account (account_chooser);
 
 	if (!EMP_STR_EMPTY (server)) {
 		room_name = g_strconcat (room, "@", server, NULL);
@@ -734,8 +737,8 @@ new_chatroom_dialog_join (EmpathyNewChatroomDialog *dialog)
 	g_strstrip (room_name);
 
 	DEBUG ("Requesting channel for '%s'", room_name);
-	empathy_dispatcher_join_muc (connection, room_name,
-		gtk_get_current_event_time (), NULL, NULL);
+	empathy_dispatcher_join_muc (account, room_name,
+		gtk_get_current_event_time ());
 
 	g_free (room_name);
 }
